pub struct RDCleanPathPdu {
pub version: u64,
pub error: Option<RDCleanPathErr>,
pub destination: Option<String>,
pub proxy_auth: Option<String>,
pub server_auth: Option<String>,
pub preconnection_blob: Option<String>,
pub x224_connection_pdu: Option<OctetString>,
pub server_cert_chain: Option<Vec<OctetString>>,
pub server_addr: Option<String>,
}Fields
version: u64RDCleanPathPdu packet version.
error: Option<RDCleanPathErr>The proxy error.
Sent from proxy to client only.
destination: Option<String>The RDP server address itself.
Sent from client to proxy only.
proxy_auth: Option<String>Arbitrary string for authorization on proxy side.
Sent from client to proxy only.
server_auth: Option<String>Currently unused. Could be used by a custom RDP server eventually.
preconnection_blob: Option<String>The RDP PCB forwarded by the proxy to the RDP server.
Sent from client to proxy only.
x224_connection_pdu: Option<OctetString>Either the client handshake or the server handshake response.
Both client and proxy will set this field.
server_cert_chain: Option<Vec<OctetString>>The RDP server TLS chain.
Sent from proxy to client only.
server_addr: Option<String>IPv4 or IPv6 address of the server found by resolving the destination field on proxy side.
Sent from proxy to client only.
Implementations
Sourceimpl RDCleanPathPdu
impl RDCleanPathPdu
Sourcepub fn from_der(src: &[u8]) -> Result<Self>
pub fn from_der(src: &[u8]) -> Result<Self>
Attempts to decode a RDCleanPath PDU from the provided buffer of bytes.
Sourcepub fn detect(src: &[u8]) -> DetectionResult
pub fn detect(src: &[u8]) -> DetectionResult
Try to parse first few bytes in order to detect a RDCleanPath PDU
pub fn into_enum(self) -> Result<RDCleanPath, MissingRDCleanPathField>
pub fn new_general_error() -> Self
pub fn new_http_error(status_code: u16) -> Self
pub fn new_request( x224_pdu: Vec<u8>, destination: String, proxy_auth: String, pcb: Option<String>, ) -> Result<Self>
pub fn new_response( server_addr: String, x224_pdu: Vec<u8>, x509_chain: impl IntoIterator<Item = Vec<u8>>, ) -> Result<Self>
pub fn new_tls_error(alert_code: u8) -> Self
pub fn new_wsa_error(wsa_error_code: u16) -> Self
Sourcepub fn new_negotiation_error(server_x224_response: Vec<u8>) -> Result<Self>
pub fn new_negotiation_error(server_x224_response: Vec<u8>) -> Result<Self>
Creates a negotiation error response that includes the server’s X.224 negotiation response.
This allows clients to extract specific negotiation failure details (like “CredSSP required”) from the server’s original response.
Example
use ironrdp_rdcleanpath::RDCleanPathPdu;
// Server rejected connection with "CredSSP required" - preserve this info
let server_response = vec![/* X.224 Connection Confirm with failure code */];
let error_pdu = RDCleanPathPdu::new_negotiation_error(server_response)?;pub fn to_der(&self) -> Result<Vec<u8>>